National Flag of Canada Day - Wikipedia

Jump to content

# National Flag of Canada Day

7 languages

- العربية
- Español
- Français
- Հայերեն
- עברית
- Bahasa Melayu
- Polski

Edit links
From Wikipedia, the free encyclopedia
Canadian holiday

National Flag of Canada Day
The national flag of Canada
Observed by | Canada
Date | February 15
Next time | February 15, 2025 (2025-02-15)
Frequency | Annual

National Flag of Canada Day (French: Jour du drapeau national du Canada), commonly shortened to Flag Day, is observed annually on February 15 to commemorate the inauguration of the flag of Canada on that date in 1965.[1] The day is marked by flying the flag, occasional public ceremonies and educational programs in schools. It is not a public holiday, although there has been discussion about creating one.

## History

[edit]

### Background

[edit]

Amid much controversy, the Parliament of Canada in 1964 voted to adopt a new design for the Canadian flag and issued a call for submissions.[2]

This flag would replace the Canadian Red Ensign, which had been, with various successive alterations, in conventional use as the national flag of Canada since 1868. Nearly 4,000 designs were submitted by Canadians.[2] On October 22, 1964, the Maple Leaf flag—designed by historian George Stanley—won with a unanimous vote.[3] Under the leadership of Prime Minister Lester Pearson, resolutions recommending the new design were passed by the House of Commons on December 15, 1964, and by the Senate two days later.[4]

The flag was proclaimed by Elizabeth II, Queen of Canada, on January 28, 1965,[3][5] and took effect "upon, from and after" February 15 that year.[6]

### Flag Day

[edit]

National Flag of Canada Day was instituted in 1996 by an Order in Council from Governor General Roméo LeBlanc, on the initiative of Prime Minister Jean Chrétien.[7] At the first Flag Day ceremony in Hull, Quebec, Chrétien was confronted by demonstrators against proposed cuts to the unemployment insurance system, and while walking through the crowd he was grabbed by the neck and pushed aside a protester who had approached him.

In 2010, on the flag's 45th anniversary, federal ceremonies were held to mark Flag Day at Ottawa, Winnipeg, St. John's, and at Whistler and Vancouver in conjunction with the 2010 Winter Olympics in Vancouver.[8] In 2011, Prime Minister Stephen Harper observed Flag Day by presenting two citizens, whose work honoured the military, with Canadian flags that had flown over the Peace Tower. It was announced as inaugurating an annual recognition of patriotism.[9]

## See also

[edit]

- Flag Day
- List of Canadian flags
- National flag

## Footnotes

[edit]

1. ^
   Department of Canadian Heritage. "Ceremonial and Canadian Symbols Promotion > The National Flag of Canada". Queen's Printer for Canada. Archived from the original on April 23, 2010. Retrieved March 21, 2010.
2. ^ a b Government of Canada, Public Services and Procurement Canada (July 31, 2015). "Infographic: National Flag of Canada Day – February 15 – Canada's Parliamentary Precinct – PWGSC". www.tpsgc-pwgsc.gc.ca. Retrieved February 5, 2022.
3. ^ a b "What is the National Flag Day of Canada?". westernfinancialgroup.ca. Retrieved February 5, 2022.
4. ^ Department of Canadian Heritage. "Ceremonial and Canadian Symbols Promotion > The National Flag of Canada > Birth of the Canadian flag". Queen's Printer for Canada. Archived from the original on February 24, 2010. Retrieved March 21, 2010.
5. ^ "Birth of the Canadian flag". Department of Canadian Heritage. Archived from the original on December 20, 2008. Retrieved December 16, 2008.
6. ^ Conserving the Proclamation of the Canadian Flag Archived October 21, 2012, at the Wayback Machine, Library and Archives of Canada, from John Grace in The Archivist, National Archives, Ottawa, 1990. Retrieved February 15, 2011.
7. ^ Department of Canadian Heritage. "National Flag of Canada Day". Queen's Printer for Canada. Archived from the original on February 17, 2010. Retrieved March 21, 2010.
8. ^ Dept. of Canadian Heritage news release Archived July 6, 2011, at the Wayback Machine, February 15, 2010. Retrieved February 15, 2011.
9. ^ PM pays tribute to outstanding Canadians on Flag Day Archived July 6, 2011, at the Wayback Machine, Prime Minister's Office news release. Retrieved February 16, 2011.

## External links

[edit]
Wikimedia Commons has media related to National Flag of Canada Day.

- Flag of Canada Song (1965) Freddie Grant
- Flag Day, Dept. of Canadian Heritage
- The famous Canadian Flag Collection, at Settlers, Rails & Trails Inc, Argyle, Manitoba

Retrieved from "https://en.wikipedia.org/w/index.php?title=National_Flag_of_Canada_Day&oldid=1231946994"
Categories:

- 1996 establishments in Canada
- Public holidays in Canada
- February observances
- Flag days
- Winter events in Canada

Hidden categories:

- Webarchive template wayback links
- Articles with short description
- Short description matches Wikidata
- Use mdy dates from February 2018
- Infobox holiday with missing field
- Infobox holiday fixed day
- Articles containing French-language text
- Commons category link is on Wikidata